%Load data
%Model.Geo = matrix of geometric position of nodes [NodeId x y z] (G x 4)
%Model.Lks = matrix of beam links [NodeId1 NodeId2 col alpha b h t ro E v c_alpha c_beta N] (L x 13)
%Model.Rod = matrix of rod links [NodeId1 NodeId2 col alpha Dy Dz t ro E v c_alpha c_beta N] (R x 13)
%Model.Sh3 = matrix of tria shell [NodeId1 NodeId2 NodeId3 col t ro E v c_alpha c_beta] (S x 10)
%Model.Sh4 = matrix of quad shell [NodeId1 NodeId2 NodeId3 NodeId4 col t ro E v c_alpha c_beta] (Q x 11)
%Model.Tet = matrix of tetra solid [NodeId1 NodeId2 NodeId3 NodeId4 col ro E v c_alpha c_beta] (T x 10)
%Model.Hex = matrix of hexa solid [NodeId1 NodeId2 NodeId3 NodeId4 NodeId5 NodeId6 NodeId7 NodeId8 col ro E v c_alpha c_beta] (H x 14)
%Model.Mss = matrix of lumped masses [NodeId m Jxx Jyy Jzz Jxy Jxz Jyz] (M x 8)
%            or [NodeId mx my mz Jxx Jxy Jxz Jyx Jyy Jyz Jzx Jzy Jzz] (M x 13)
%Model.Dmp = matrix of lumped dampers [NodeId1 dof1 NodeId2 dof2 c] (C x 5)
%Model.ab  = vector of the viscous damping coefficients [c_alpha; c_beta] (2 x 1)
%Model.dTb = matrix of modal damping profile [c_freq zeta] (Z x 2)
%Model.Om  = scalar of gyroscopic spin speed [Om] (1 x 1)
%Model.Els = matrix of lumped springs [NodeId1 dof1 NodeId2 dof2 k] (K x 5)
%Model.RJs = matrix with rigid joints [NodeId1 NodeId2] (J x 2)
%Model.RBE = matrix with rigid body elements [NodeId1 dof1 NodeId2 dof2] (B x 4)
%Model.BCs = matrix with dofs to be deleted [NodeId dof] (V x 2)
%Model.FMs = matrix with generalised forces [NodeId dof Amp] (F x 3)
%Model.IKs = matrix with dofs with imposed kinematics [NodeId dof] (I x 2)
%Model.Grv = vector of generalised gravity [gx gy gz] (1 x 3) eg. [0 0 -9.81]
%Model.Nodes_se = matrix with dofs for super-element matrices [NodeId dof] (E x 2)
%Model.M_se     = super-element mass matrix (E x E)
%Model.C_se     = super-element damping matrix (E x E)
%Model.K_se     = super-element stiffness matrix (E x E)

%% INERTIAL PROPERTIES
% Chassis
Car.m = 11.95;                                                             % Sprung mass (chassis) [kg]
Car.Ix = 0.10929;                                                          % Moment of inertia around X [kg*m^2]
Car.Iy = 0.725;                                                            % Moment of inertia around Y [kg*m^2]
Car.Iz = 0.74771;                                                          % Moment of inertia around Z [kg*m^2]
% Body
if body_case == 2
    Car.mb = 2.2825;                                                       % Sprung mass (body) [kg]
    Car.Ixb = 0.0273;                                                     % Moment of inertia around X [kg*m^2]
    Car.Iyb = 0.14033;                                                     % Moment of inertia around Y [kg*m^2]
    Car.Izb = 0.16521;                                                     % Moment of inertia around Z [kg*m^2]
end
Car.m1 = 2.495/4;                                                          % Unsprung mass of a single front wheel [kg]
Car.m2 = 2.495/4;                                                          % Unsprung mass of a single rear wheel [kg]

%% GEOMETRICAL DATA
Car.L = 0.965;                                                             % Lenght [m]
Car.B = 0.527;                                                             % Width [m]
Car.H = 0.311;                                                             % Height [m]
% Chassis Barycentre location
Car.a = 0.61;                                                              % Wheelbase [m]
Car.a1 = 0.305;                                                            % Front semi-wheelbase [m]
Car.a2 = Car.a-Car.a1;                                                     % Rear semi-wheelbase [m]
Car.t = 0.456;                                                             % Track [m]
Car.h = 0.04;                                                              % Ground clearance of the upper surface of the plate (blue spring, ring unscrewed) [m]
Car.hG = 0.054+Car.h;                                                      % Barycentre height [m]
% Body Barycentre location 
if body_case == 2
    Car.a1b = 0.352;                                                       % Front semi-wheelbase [m]
    Car.a2b = 0.257;                                                       % Rear semi-wheelbase [m]
    Car.hb = 0.03;                                                         % Ground clearance of the upper surface of the plate (blue spring, ring unscrewed) [m]
    Car.hGb = 0.212+Car.hb;                                                % Barycentre height [m]
end

% Tyre 225/55 R17
Car.TyreL = 0.071;                                                         % Width [m]
Car.TyreH = Car.TyreL*0.55;                                                % Side height [m]
Car.TyreD = 0.181;                                                         % External diameter [m]

% Suspension connection locations 
% Front up
Car.FSuspUp.x = 0.022;
Car.FSuspUp.y = 0.04;
Car.FSuspUp.z = 0.13;
% Front low
Car.FSuspLow.x = 0.0335;
Car.FSuspLow.y = 0.112;
Car.FSuspLow.z = -0.012;
% Rear up
Car.RSuspUp.x = -0.64;
Car.RSuspUp.y = 0.075;
Car.RSuspUp.z = 0.123;
% Rear low
Car.RSuspLow.x = -0.655;
Car.RSuspLow.y = 0.15;
Car.RSuspLow.z = -0.012;

% Top Arm location  
% Front
Car.FArm.x1 = -0.007;                                                      % Node Arm to Chassis
Car.FArm.y1 = 0.035;                                                       % Node Arm to Chassis
Car.FArm.z1 = 0.080;                                                       % Node Arm to Chassis
Car.FArm.x2 = -0.010;                                                      % Node Arm to Wheel
Car.FArm.y2 = 0.171;                                                       % Node Arm to Wheel
Car.FArm.z2 = 0.070;                                                       % Node Arm to Wheel
% Rear
Car.RArm.x1 = -0.6125;                                                     % Node Arm to Chassis
Car.RArm.y1 = 0.060;                                                       % Node Arm to Chassis
Car.RArm.z1 = 0.060;                                                       % Node Arm to Chassis
Car.RArm.x2 = -0.6125;                                                     % Node Arm to Wheel
Car.RArm.y2 = 0.160;                                                       % Node Arm to Wheel
Car.RArm.z2 = 0.060;                                                       % Node Arm to Wheel

% Rig-nut of shock-absorber dependence
delta_h = 0;                                                               % height increasing due to the screwing of rig-nut
d1_f = abs(Car.FSuspLow.y-0.04);                                           % lenght low arm (right part) FRONT
d2_f = abs(Car.t/2-Car.FSuspLow.y);                                        % lenght low arm (left part)FRONT
d_f = d1_f+d2_f;                                                           % lenght low arm FRONT
alf_f = atan(delta_h/(sqrt(d_f^2-delta_h^2)));                             % angle FRONT
deltayc_f = d_f-sqrt(d_f^2-delta_h^2);                                     % decreasing of semi-track FRONT
deltazb_f = d2_f*sin(alf_f);                                               % increasing of height of low arm node FRONT
yb_f = 0.04+d1_f*cos(alf_f);                                               % y-coordinate of low arm node FRONT
d1_r = abs(Car.RSuspLow.y-0.04);                                           % lenght low arm (right part) REAR
d2_r = abs(Car.t/2-Car.RSuspLow.y);                                        % lenght low arm (left part)REAR
d_r = d1_r+d2_r;                                                           % lenght low arm REAR
alf_r = atan(delta_h/(sqrt(d_r^2-delta_h^2)));                             % angle REAR
deltayc_r = d_r-sqrt(d_r^2-delta_h^2);                                     % decreasing of semi-track REAR
deltazb_r = d2_r*sin(alf_r);                                               % increasing of height of low arm node REAR
yb_r = 0.04+d1_r*cos(alf_r);                                               % y-coordinate of low arm node REAR

%% Nominal stiffness and damping coefficient
% Suspension
Car.FSusp.c.n = 5.7e3;                                                     % Front damping value [Ns/m]
Car.RSusp.c.n = 4.5e3;                                                     % Rear damping value [Ns/m]
% Tyres
Car.FTyres.k = 18277;                                                       % Front tyre stiffness [N/m]
Car.RTyres.k = 18277;                                                       % Rear tyre stiffness [N/m]
Car.FTyres.c = 50;                                                         % Front tyre damping [Ns/m]
Car.RTyres.c = 50;                                                         % Rear tyre damping [Ns/m]

%% Parametric analysis
disp('PARAMETRIC ANALYSIS')
disp('Suspension Stiffness Parametric Analysis')
if param_k == 1
K_S1 = [2046.24 1816.92 2275.56 2504.88].';                        % Front spring stiffness [N/m]
Car.FSusp.k.n = K_S1(K_S1_i);
Car.RSusp.k.n = config;                                            % Rear spring stiffness [N/m
end
if param_k == 2
K_S2 = [1411.2 1640 1887.48].';                                    % Rear spring stiffness [N/m]
Car.FSusp.k.n = config;                                            % Front spring stiffness [N/m]
Car.RSusp.k.n = K_S2(K_S2_i);                                      
end
disp('---------------------------------------------------------------------')
disp('Suspension Characteristics')
disp(['Front Stiffnesses: ', num2str(round(Car.FSusp.k.n)), ' [N/m]', ...
      '   Front Dampings: ', num2str(round(Car.FSusp.c.n)), ' [Ns/m]';...
      'Rear Stiffnesses:  ', num2str(round(Car.RSusp.k.n)), ' [N/m]', ...
      '   Rear Dampings:  ', num2str(round(Car.RSusp.c.n)), ' [Ns/m]']);
disp('Tyre Characteristics')
disp(['Front Tyre Stiffnesses: ', num2str(round(Car.FTyres.k)), ' [N/m]', ...
      '   Front Tyre Dampings: ', num2str(round(Car.FTyres.c)), ' [Ns/m]';...
      'Rear Tyre Stiffnesses:  ', num2str(round(Car.RTyres.k)), ' [N/m]', ...
      '   Rear Tyre Dampings:  ', num2str(round(Car.RTyres.c)), ' [Ns/m]']); 
disp('---------------------------------------------------------------------')

%% Components of stiffness and damping of suspension 
% Front Suspension 
Car.FSusp.x = Car.FSuspLow.x-Car.FSuspUp.x;                                %x-component Up-Low vector
Car.FSusp.y = Car.FSuspLow.y-Car.FSuspUp.y;                                %y-component Up-Low vector
Car.FSusp.z = Car.FSuspLow.z-Car.FSuspUp.z;                                %z-component Up-Low vector
Car.FSusp.r = sqrt(Car.FSusp.x^2+Car.FSusp.y^2+Car.FSusp.z^2);             %Modulus vector Low-Up vector
Car.FSusp.alpha1 = asin(abs(Car.FSusp.z/Car.FSusp.r));                     %angle between vector Low-Up and its projection on xy plane
Car.FSusp.alpha2 = atan(abs(Car.FSusp.x/Car.FSusp.y));                     %angle between projection on xy plane and y-component
Car.FSusp.k.x = (Car.FSusp.k.n*cos(Car.FSusp.alpha1))*sin(Car.FSusp.alpha2); %x-stiffness 
Car.FSusp.k.y = (Car.FSusp.k.n*cos(Car.FSusp.alpha1))*cos(Car.FSusp.alpha2); %y-stiffness
Car.FSusp.k.z = Car.FSusp.k.n*sin(Car.FSusp.alpha1);                         %z-stiffness
Car.FSusp.c.x = (Car.FSusp.c.n*cos(Car.FSusp.alpha1))*sin(Car.FSusp.alpha2); %x-damping
Car.FSusp.c.y = (Car.FSusp.c.n*cos(Car.FSusp.alpha1))*cos(Car.FSusp.alpha2); %y-damping
Car.FSusp.c.z = Car.FSusp.c.n*sin(Car.FSusp.alpha1);                         %z-damping
% Rear Suspension 
Car.RSusp.x = Car.RSuspLow.x-Car.RSuspUp.x;                                %x-component Up-Low
Car.RSusp.y = Car.RSuspLow.y-Car.RSuspUp.y;                                %y-component Up-Low
Car.RSusp.z = Car.RSuspLow.z-Car.RSuspUp.z;                                %z-component Up-Low
Car.RSusp.r = sqrt(Car.RSusp.x^2+Car.RSusp.y^2+Car.RSusp.z^2);             %Modulus vector Low-Up
Car.RSusp.alpha1 = asin(abs(Car.RSusp.z/Car.RSusp.r));                     %angle between vector Low-Up and its projection on xy plane
Car.RSusp.alpha2 = atan(abs(Car.RSusp.x/Car.RSusp.y));                     %angle between projection on xy plane and y-component
Car.RSusp.k.x = (Car.RSusp.k.n*cos(Car.RSusp.alpha1))*sin(Car.RSusp.alpha2); %x-stiffness 
Car.RSusp.k.y = (Car.RSusp.k.n*cos(Car.RSusp.alpha1))*cos(Car.RSusp.alpha2); %y-stiffness
Car.RSusp.k.z = Car.RSusp.k.n*sin(Car.RSusp.alpha1);                         %z-stiffness
Car.RSusp.c.x = (Car.RSusp.c.n*cos(Car.RSusp.alpha1))*sin(Car.RSusp.alpha2); %x-damping
Car.RSusp.c.y = (Car.RSusp.c.n*cos(Car.RSusp.alpha1))*cos(Car.RSusp.alpha2); %y-damping
Car.RSusp.c.z = Car.RSusp.c.n*sin(Car.RSusp.alpha1);                         %z-damping

%% Chassis loading
Geo_chassis = [
    100    -Car.a1                          0          -Car.TyreD/2+Car.hG+delta_h    % Chassis barycentre
    106     Car.FSuspUp.x       Car.FSuspUp.y           Car.FSuspUp.z+delta_h         % FL up spring
    107     Car.FSuspUp.x      -Car.FSuspUp.y           Car.FSuspUp.z+delta_h         % FR up spring
    108     Car.RSuspUp.x       Car.RSuspUp.y           Car.RSuspUp.z+delta_h         % RL up spring
    109     Car.RSuspUp.x      -Car.RSuspUp.y           Car.RSuspUp.z+delta_h         % RR up spring
    206     Car.FSuspLow.x      yb_f                    Car.FSuspLow.z+deltazb_f           % FL low spring
    207     Car.FSuspLow.x     -yb_f                    Car.FSuspLow.z+deltazb_f           % FR low spring
    208     Car.RSuspLow.x      yb_r                    Car.RSuspLow.z+deltazb_r           % RL low spring
    209     Car.RSuspLow.x     -yb_r                    Car.RSuspLow.z+deltazb_r           % RR low spring
    306     0                  Car.t/2-deltayc_f       -Car.TyreD/2                        % Contact point of FL wheel
    307     0                 -Car.t/2+deltayc_f       -Car.TyreD/2                        % Contact point of FR wheel
    308    -Car.a1-Car.a2      Car.t/2-deltayc_r       -Car.TyreD/2                        % Contact point of RL wheel
    309    -Car.a1-Car.a2     -Car.t/2+deltayc_r       -Car.TyreD/2                        % Contact point of RR wheel
    406     0                     0.04                  Car.FSuspLow.z+delta_h        % FL susp. arm to chassis
    407     0                    -0.04                  Car.FSuspLow.z+delta_h        % FR susp. arm to chassis
    408    -Car.a1-Car.a2         0.04                  Car.RSuspLow.z+delta_h        % RL susp. arm to chassis
    409    -Car.a1-Car.a2        -0.04                  Car.RSuspLow.z+delta_h        % RR susp. arm to chassis
    501    -Car.a1+Car.L/2          0                  -Car.TyreD/2+Car.hG+delta_h    % Vehicle sketch
    502     0                       0                  -Car.TyreD/2+Car.hG+delta_h    % Vehicle sketch
    503    -Car.a1                  0                  -Car.TyreD/2+Car.hG+delta_h    % Vehicle sketch
    504    -Car.a1-Car.a2           0                  -Car.TyreD/2+Car.hG+delta_h    % Vehicle sketch
    505    -Car.a1-Car.L/2          0                  -Car.TyreD/2+Car.hG+delta_h    % Vehicle sketch
    506     0                     yb_f                  Car.FSuspLow.z+deltazb_f           % FL node of arm wheel-chassis
    507     0                    -yb_f                  Car.FSuspLow.z+deltazb_f           % FR node of arm wheel-chassis
    508    -Car.a1-Car.a2         yb_r                  Car.RSuspLow.z+deltazb_r           % RL node of arm wheel-chassis
    509    -Car.a1-Car.a2        -yb_r                  Car.RSuspLow.z+deltazb_r           % RR node of arm wheel-chassis
    601     0                     Car.t/2-deltayc_f         0                              % FL wheel
    602     0             Car.t/2+Car.TyreL/2-deltayc_f     0                              % FL wheel sketch
    603     0             Car.t/2-Car.TyreL/2-deltayc_f     0                              % FL wheel sketch
    611     Car.FArm.x2           Car.FArm.y2-deltayc_f Car.FArm.z2                        % FL Arm to wheel
    621     Car.FArm.x1           Car.FArm.y1           Car.FArm.z1+delta_h           % FL Arm to chassis
    701     0                    -Car.t/2+deltayc_f         0                              % FR wheel
    702     0               -Car.t/2-Car.TyreL/2+deltayc_f  0                              % FR wheel sketch
    703     0               -Car.t/2+Car.TyreL/2+deltayc_f  0                              % FR wheel sketch
    711     Car.FArm.x2          -Car.FArm.y2+deltayc_f Car.FArm.z2                        % FR Arm to wheel
    721     Car.FArm.x1          -Car.FArm.y1           Car.FArm.z1+delta_h           % FR Arm to chassis
    801    -Car.a1-Car.a2         Car.t/2-deltayc_r         0                              % RL wheel
    802    -Car.a1-Car.a2    Car.t/2+Car.TyreL/2-deltayc_r  0                              % RL wheel sketch
    803    -Car.a1-Car.a2    Car.t/2-Car.TyreL/2-deltayc_r  0                              % RL wheel sketch
    811     Car.RArm.x2           Car.RArm.y2-deltayc_r Car.RArm.z2                        % RL Arm to wheel
    821     Car.RArm.x1           Car.RArm.y1           Car.RArm.z1+delta_h           % RL Arm to chassis
    901    -Car.a1-Car.a2        -Car.t/2+deltayc_r         0                              % RR wheel
    902    -Car.a1-Car.a2   -Car.t/2-Car.TyreL/2+deltayc_r  0                              % RR wheel sketch
    903    -Car.a1-Car.a2   -Car.t/2+Car.TyreL/2+deltayc_r  0                              % RR wheel sketch
    911     Car.RArm.x2          -Car.RArm.y2+deltayc_r Car.RArm.z2                        % RR Arm to wheel
    921     Car.RArm.x1          -Car.RArm.y1           Car.RArm.z1+delta_h           % RR Arm to chassis
    1006    0                     0.04                  Car.FSuspLow.z+delta_h        % FL susp. arm to chassis
    1007    0                    -0.04                  Car.FSuspLow.z+delta_h        % FR susp. arm to chassis
    1008   -Car.a1-Car.a2         0.04                  Car.RSuspLow.z+delta_h        % RL susp. arm to chassis
    1009   -Car.a1-Car.a2        -0.04                  Car.RSuspLow.z+delta_h        % RR susp. arm to chassis
    1611    Car.FArm.x2           Car.FArm.y2-deltayc_f Car.FArm.z2                        % FL Arm to wheel
    1621    Car.FArm.x1           Car.FArm.y1           Car.FArm.z1+delta_h           % FL Arm to chassis
    1711    Car.FArm.x2          -Car.FArm.y2+deltayc_f Car.FArm.z2                        % FR Arm to wheel
    1721    Car.FArm.x1          -Car.FArm.y1           Car.FArm.z1+delta_h           % FR Arm to chassis
    1811    Car.RArm.x2           Car.RArm.y2-deltayc_r Car.RArm.z2                        % RL Arm to wheel
    1821    Car.RArm.x1           Car.RArm.y1           Car.RArm.z1+delta_h           % RL Arm to chassis
    1911    Car.RArm.x2          -Car.RArm.y2+deltayc_r Car.RArm.z2                        % RR Arm to wheel
    1921    Car.RArm.x1          -Car.RArm.y1           Car.RArm.z1+delta_h           % RR Arm to chassis
    2006    0                     Car.t/2-deltayc_f         0                              % FL susp. arm to wheel
    2007    0                    -Car.t/2+deltayc_f         0                              % FR susp. arm to wheel
    2008   -Car.a1-Car.a2         Car.t/2-deltayc_r         0                              % RL susp. arm to wheel
    2009   -Car.a1-Car.a2        -Car.t/2+deltayc_r         0                              % RR susp. arm to wheel
    3006    0                     Car.t/2-deltayc_f         0                              % FL top arm to wheel
    3007    0                    -Car.t/2+deltayc_f         0                              % FR top arm to wheel
    3008   -Car.a1-Car.a2         Car.t/2-deltayc_r         0                              % RL top arm to wheel
    3009   -Car.a1-Car.a2        -Car.t/2+deltayc_r         0                              % RR top arm to wheel
    5004  0.065                    0.02              Car.FSuspLow.z+0.031+delta_h     % FL Antiroll hook
    5104  0.065                   -0.02              Car.FSuspLow.z+0.031+delta_h     % FR Antiroll hook
    5204  -Car.a1-Car.a2-0.07     0.026              Car.RSuspLow.z+0.027+delta_h     % RL Antiroll hook
    5304  -Car.a1-Car.a2-0.07    -0.026              Car.RSuspLow.z+0.027+delta_h     % RR Antiroll hook
    ];

ro_eq = 0;                                                                 % Rigid elements density
E_eq = 1e14;                                                               % Rigid elements Young Modulus

   
Rod_chassis = [
    206  506  5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FL Joint arm to spring
    207  507  5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FR Joint arm to spring
    208  508  5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RL Joint arm to spring
    209  509  5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RR Joint arm to spring
    406  502  4  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % Chassis to FL Joint arm
    407  502  4  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % Chassis to FR Joint arm
    408  504  4  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % Chassis to RL Joint arm
    409  504  4  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % Chassis to RR Joint arm
    502  1621 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FL Top Arm to Chassis connection
    502  1721 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FR Top Arm to Chassis connection
    502  5004 4  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FL Chassis for Antiroll Hook
    502  5104 4  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FR Chassis for Antiroll Hook
    504  1821 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RL Top Arm to Chassis connection
    504  1921 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RR Top Arm to Chassis connection
    504  5204 4  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RL Chassis for Antiroll Hook
    504  5304 4  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RR Chassis for Antiroll Hook
    506  1006 5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FL Joint arm  
    506  2006 5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FL Joint arm to wheel
    507  1007 5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FR Joint arm  
    507  2007 5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FR Joint arm to wheel
    508  1008 5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RL Joint arm 
    508  2008 5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RL Joint arm to wheel
    509  1009 5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RR Joint arm
    509  2009 5  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RR Joint arm to wheel
    602  603  2  0  Car.TyreD  Car.TyreD  Car.TyreH   1e-6   1e-8  0.3     % FL wheel sketch
    611  3006 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FL Top Beam-Wheel connection
    621  1611 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FL Top Arm 
    702  703  2  0  Car.TyreD  Car.TyreD  Car.TyreH   1e-6   1e-8  0.3     % FR wheel sketch
    711  3007 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FR Top Arm-Wheel connection
    721  1711 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % FR Top Arm 
    802  803  2  0  Car.TyreD  Car.TyreD  Car.TyreH   1e-6   1e-8  0.3     % RL wheel sketch
    811  3008 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RL Top Arm-Wheel connection
    821  1811 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RL Top Arm 
    902  903  2  0  Car.TyreD  Car.TyreD  Car.TyreH   1e-6   1e-8  0.3     % RR wheel sketch
    911  3009 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RR Top Arm-Wheel connection
    921  1911 3  0  0.01        0.01       -1         ro_eq  E_eq  0.3     % RR Top Arm 
    ];
RBE_chassis = [
    100 1  503 1                                                  % Vehicle sketch to G
    100 2  503 2                                                  % Vehicle sketch to G
    100 3  503 3                                                  % Vehicle sketch to G
    100 4  503 4                                                  % Vehicle sketch to G
    100 5  503 5                                                  % Vehicle sketch to G
    100 6  503 6                                                  % Vehicle sketch to G
    406 1  1006 1                                                 % FL arm joint
    406 2  1006 2                                                 % FL arm joint
    406 3  1006 3                                                 % FL arm joint
    406 5  1006 5                                                 % FL arm joint
    406 6  1006 6                                                 % FL arm joint
    407 1  1007 1                                                 % FR arm joint
    407 2  1007 2                                                 % FR arm joint
    407 3  1007 3                                                 % FR arm joint
    407 5  1007 5                                                 % FR arm joint
    407 6  1007 6                                                 % FR arm joint
    408 1  1008 1                                                 % RL arm joint
    408 2  1008 2                                                 % RL arm joint
    408 3  1008 3                                                 % RL arm joint
    408 5  1008 5                                                 % RL arm joint
    408 6  1008 6                                                 % RL arm joint
    409 1  1009 1                                                 % RR arm joint
    409 2  1009 2                                                 % RR arm joint
    409 3  1009 3                                                 % RR arm joint
    409 5  1009 5                                                 % RR arm joint
    409 6  1009 6                                                 % RR arm joint
    601 1  2006  1                                                % FL joint wheel-low arm
    601 2  2006  2                                                % FL joint wheel-low arm
    601 3  2006  3                                                % FL joint wheel-low arm
    601 5  2006  5                                                % FL joint wheel-low arm
    601 6  2006  6                                                % FL joint wheel-low arm
    601 1  3006  1                                                % FL joint wheel-top arm
    601 2  3006  2                                                % FL joint wheel-top arm
    601 3  3006  3                                                % FL joint wheel-top arm 
    601 4  3006  4                                                % FL joint wheel-top arm
    601 5  3006  5                                                % FL joint wheel-top arm
    601 6  3006  6                                                % FL joint wheel-top arm
    611 1  1611  1                                                % FL Spherical joint Top Arm-wheel
    611 2  1611  2                                                % FL Spherical joint Top Arm-wheel
    611 3  1611  3                                                % FL Spherical joint Top Arm-wheel
    611 5  1611  5                                                % FL Spherical joint Top Arm-wheel
    621 1  1621  1                                                % FL Spherical joint Top Arm-chassis
    621 2  1621  2                                                % FL Spherical joint Top Arm-chassis
    621 3  1621  3                                                % FL Spherical joint Top Arm-chassis
    701 1  2007  1                                                % FR joint wheel-low arm
    701 2  2007  2                                                % FR joint wheel-low arm
    701 3  2007  3                                                % FR joint wheel-low arm
    701 5  2007  5                                                % FR joint wheel-low arm
    701 6  2007  6                                                % FR joint wheel-low arm
    701 1  3007  1                                                % FR joint wheel-top arm
    701 2  3007  2                                                % FR joint wheel-top arm
    701 3  3007  3                                                % FR joint wheel-top arm
    701 4  3007  4                                                % FR joint wheel-top arm
    701 5  3007  5                                                % FR joint wheel-top arm
    701 6  3007  6                                                % FR joint wheel-top arm
    711 1  1711  1                                                % FR Spherical joint Top Arm-wheel
    711 2  1711  2                                                % FR Spherical joint Top Arm-wheel
    711 3  1711  3                                                % FR Spherical joint Top Arm-wheel
    711 5  1711  5                                                % FR Spherical joint Top Arm-wheel
    721 1  1721  1                                                % FR Spherical joint Top Arm-chassis
    721 2  1721  2                                                % FR Spherical joint Top Arm-chassis
    721 3  1721  3                                                % FR Spherical joint Top Arm-chassis
    801 1  2008  1                                                % RL joint wheel-low arm
    801 2  2008  2                                                % RL joint wheel-low arm
    801 3  2008  3                                                % RL joint wheel-low arm
    801 5  2008  5                                                % RL joint wheel-low arm
    801 6  2008  6                                                % RL joint wheel-low arm
    801 1  3008  1                                                % RL joint wheel-top arm
    801 2  3008  2                                                % RL joint wheel-top arm
    801 3  3008  3                                                % RL joint wheel-top arm
    801 4  3008  4                                                % RL joint wheel-top arm
    801 5  3008  5                                                % RL joint wheel-top arm
    801 6  3008  6                                                % RL joint wheel-top arm
    811 1  1811  1                                                % RL Spherical joint Top Arm-wheel
    811 2  1811  2                                                % RL Spherical joint Top Arm-wheel
    811 3  1811  3                                                % RL Spherical joint Top Arm-wheel
    811 5  1811  5                                                % RL Spherical joint Top Arm-wheel
    821 1  1821  1                                                % RL Spherical joint Top Arm-chassis
    821 2  1821  2                                                % RL Spherical joint Top Arm-chassis
    821 3  1821  3                                                % RL Spherical joint Top Arm-chassis
    901 1  2009  1                                                % RR joint wheel-low arm
    901 2  2009  2                                                % RR joint wheel-low arm
    901 3  2009  3                                                % RR joint wheel-low arm
    901 5  2009  5                                                % RR joint wheel-low arm
    901 6  2009  6                                                % RR joint wheel-low arm
    901 1  3009  1                                                % RR joint wheel-top arm
    901 2  3009  2                                                % RR joint wheel-top arm
    901 3  3009  3                                                % RR joint wheel-top arm
    901 4  3009  4                                                % RR joint wheel-top arm
    901 5  3009  5                                                % RR joint wheel-top arm
    901 6  3009  6                                                % RR joint wheel-top arm
    911 1  1911  1                                                % RR Revolute joint Top Arm-wheel
    911 2  1911  2                                                % RR Revolute joint Top Arm-wheel
    911 3  1911  3                                                % RR Revolute joint Top Arm-wheel
    911 5  1911  5                                                % RR Revolute joint Top Arm-wheel
    921 1  1921  1                                                % RR Revolute joint Top Arm-chassis
    921 2  1921  2                                                % RR Revolute joint Top Arm-chassis
    921 3  1921  3                                                % RR Revolute joint Top Arm-chassis
    ];
Mss_chassis = [
    100  Car.m            Car.Ix  Car.Iy  Car.Iz  0  0  0                  % Sprung mass
    601  Car.m1           0       0       0       0  0  0                  % FL unsprung mass
    701  Car.m1           0       0       0       0  0  0                  % FR unsprung mass
    801  Car.m2           0       0       0       0  0  0                  % RL unsprung mass
    901  Car.m2           0       0       0       0  0  0                  % RR unsprung mass
    ];
RJs_chassis = [
    502   106                                                              % G to FL up spring
    502   107                                                              % G to FR up spring
    502   501                                                              % Vehicle sketch
    503   502                                                              % Vehicle sketch
    503   504                                                              % Vehicle sketch
    504   108                                                              % G to RL up spring
    504   109                                                              % G to RR up spring
    504   505                                                              % Vehicle sketch
    601   602                                                              % FL Wheel hub
    601   603                                                              % FL Wheel hub
    701   702                                                              % FR Wheel hub
    701   703                                                              % FR Wheel hub
    801   802                                                              % RL Wheel hub
    801   803                                                              % RL Wheel hub
    901   902                                                              % RR Wheel hub
    901   903                                                              % RR Wheel hub
    ];
%% CHASSIS AND BODY CASE
switch body_case
    case 1                                                                           % CHASSIS CASE
        disp('CHASSIS CASE')
        Geo_Vehicle = [
              Geo_chassis
              ];
        Rod_Vehicle = [
            Rod_chassis
            ];
        Model.Mss = [
             Mss_chassis
            ];
        Model.RJs = [
            RJs_chassis
            ];
    case 2                                                                           % BODY CASE
        disp('BODY CASE')
        Geo_Vehicle = [
              Geo_chassis(1:66,:)
              3100   -Car.a1b                 0             -Car.TyreD/2+Car.hGb+delta_h   % Body barycentre
              3101   -Car.a1+Car.L/2-0.06     0.08           0.05+delta_h                  % Body-chassis attach Front Left
              3102   -Car.a1+Car.L/2-0.06    -0.08           0.05+delta_h                  % Body-chassis attach Front Right
              3103   -Car.a1-Car.L/2          0.265/2        0.085+delta_h                 % Body-chassis attach Rear Left
              3104   -Car.a1-Car.L/2         -0.265/2        0.085+delta_h                 % Body-chassis attach Front Left
              Geo_chassis(67:end,:)
            ];  
        Model.RJs = [
           501 3101 
           501 3102 
           RJs_chassis(1:8,:)
           505 3103
           505 3104 
           RJs_chassis(9:end,:)
           ];
        Rod_Vehicle = [
            Rod_chassis
           3100 3101 1  0  0.01        0.01       -1         ro_eq  E_eq  0.3       % Body sketch
           3100 3102 1  0  0.01        0.01       -1         ro_eq  E_eq  0.3       % Body sketch 
           3100 3103 1  0  0.01        0.01       -1         ro_eq  E_eq  0.3       % Body sketch 
           3100 3104 1  0  0.01        0.01       -1         ro_eq  E_eq  0.3       % Body sketch 
            ];
      
         Model.Mss = [
             Mss_chassis
             3100  Car.mb      Car.Ixb   Car.Iyb   Car.Izb  0  0  0                 % Sprung mass (body)
            ];
 end
   
%% Do you want to insert Anti-roll bars?
switch bars_case
    case 1                                                                 % Model without anti-roll bars
        disp('WITHOUT ANTI-ROLL BARS')
        % Model
        Model.Geo = [
            Geo_Vehicle
            ];
        Model.Rod = [
            Rod_Vehicle
            ];
        Model.RBE = [
            RBE_chassis
             ];
    case 2                                                                 % Model with anti-roll bars
% ANTIROLL BARS LOADING
      
if bars_which == 1 || bars_which == 3                                      % FRONT ANTI-ROLL BARS

ro_steel = 7800;       % density steel material [kg/m3]
E_steel = 210e9;       % Young modulus material [Pa]

% Low arm - left side location (node 506)
Antiroll.Front.LowArm.x = 0;
Antiroll.Front.LowArm.y = yb_f;
Antiroll.Front.LowArm.z = Car.FSuspLow.z;

% Geometric Left Side definition
Geo_Front_Antiroll_bar_l = [
    4001   Antiroll.Front.LowArm.x        Antiroll.Front.LowArm.y         Antiroll.Front.LowArm.z++deltazb_f          % Low arm node
    4002   Antiroll.Front.LowArm.x        Antiroll.Front.LowArm.y-0.008   Antiroll.Front.LowArm.z+0.031+delta_h  % Antiroll-Hardware node
    4003   Antiroll.Front.LowArm.x+0.025  Antiroll.Front.LowArm.y-0.006   Antiroll.Front.LowArm.z+0.031+delta_h  % Antiroll node
    4004   Antiroll.Front.LowArm.x+0.065           0.02                   Antiroll.Front.LowArm.z+0.031+delta_h  % Antiroll node
    4012   Antiroll.Front.LowArm.x        Antiroll.Front.LowArm.y-0.008   Antiroll.Front.LowArm.z+0.031+delta_h  % Antiroll-Hardware joint
    ];

Rod_Front_Antiroll_bar_l = [
    4001  4012  4    0  0.008   0.004 -1   ro_eq     E_eq     0.3          % Plastic Hardware
    4002  4003  1    0  0.0035  0.0035 -1  ro_steel  E_steel  0.3          % Antiroll vertical arm
    4003  4004  1    0  0.0035  0.0035 -1  ro_steel  E_steel  0.3          % Antiroll oblique arm
    ];
RBE_Front_Antiroll_bar_l = [
       4002 1 4012 1                                                       % Antiroll-Hardware joint
       4002 2 4012 2                                                       % Antiroll-Hardware joint
       4002 3 4012 3                                                       % Antiroll-Hardware joint
       4002 6 4012 6                                                       % Antiroll-Hardware joint
       ];

% Mirroring
% The left entites 40xx are duplicated for the right side 41xx
Geo_Front_Antiroll_bar_r = Geo_Front_Antiroll_bar_l;                       % Defining the Geometry for the right side
Geo_Front_Antiroll_bar_r(:,1) = Geo_Front_Antiroll_bar_r(:,1)+100;         % Naming the right side nodes 
Geo_Front_Antiroll_bar_r(:,3) = Geo_Front_Antiroll_bar_r(:,3)*(-1);        % Mirror

Rod_Front_Antiroll_bar_r = Rod_Front_Antiroll_bar_l;                       % Defining the Rod
Rod_Front_Antiroll_bar_r(:,[1 2]) = Rod_Front_Antiroll_bar_r(:,[1 2])+100; % Naming the right side nodes

RBE_Front_Antiroll_bar_r = RBE_Front_Antiroll_bar_l;                       % Defining the RBE
RBE_Front_Antiroll_bar_r(:,[1 3]) = RBE_Front_Antiroll_bar_r(:,[1 3])+100; % Naming the right side nodes

% Assembly of entities
Geo_Front_Antiroll_bar = [
    Geo_Front_Antiroll_bar_l
    Geo_Front_Antiroll_bar_r
    ];
clear Geo_Front_Antiroll_bar_l Geo_Front_Antiroll_bar_r
Rod_Front_Antiroll_bar = [ 
    Rod_Front_Antiroll_bar_l
    4004  4104  1    0  0.0035  0.0035 -1  ro_steel  E_steel  0.3          % link between left and right sides
    Rod_Front_Antiroll_bar_r
    ];
clear Rod_Front_Antiroll_bar_l Rod_Front_Antiroll_bar_r
RBE_Front_Antiroll_bar = [
    RBE_Front_Antiroll_bar_l
    RBE_Front_Antiroll_bar_r
    ];
clear RBE_Front_Antiroll_bar_l RBE_Front_Antiroll_bar_r
end
if bars_which ==2 || bars_which == 3                                       % REAR ANTI-ROLL BAR
    
ro_steel = 7800;       % density steel material [kg/m3]
E_steel = 210e9;       % Young modulus material [Pa]

% Low arm - left side location (node 508)
Antiroll.Rear.LowArm.x = -0.610;
Antiroll.Rear.LowArm.y = yb_r;
Antiroll.Rear.LowArm.z = -0.012;

% Geometric Left Side definition
Geo_Rear_Antiroll_bar_l = [
    4201   Antiroll.Rear.LowArm.x        Antiroll.Rear.LowArm.y         Antiroll.Rear.LowArm.z+deltazb_r         % Low arm node
    4202   Antiroll.Rear.LowArm.x        Antiroll.Rear.LowArm.y-0.008   Antiroll.Rear.LowArm.z+0.027+delta_h   % Antiroll-Hardware node
    4203   Antiroll.Rear.LowArm.x-0.02   Antiroll.Rear.LowArm.y-0.012   Antiroll.Rear.LowArm.z+0.027+delta_h   % Antiroll node
    4204   Antiroll.Rear.LowArm.x-0.07           0.026                  Antiroll.Rear.LowArm.z+0.027+delta_h   % Antiroll node
    4212   Antiroll.Rear.LowArm.x        Antiroll.Rear.LowArm.y-0.008   Antiroll.Rear.LowArm.z+0.027+delta_h   % Antiroll-Hardware joint
    ];
% Beam and Rod Left Side definition
Rod_Rear_Antiroll_bar_l = [
    4201  4212  4    0  0.008   0.004  -1  ro_eq     E_eq     0.3          % Plastic Hardware
    4202  4203  1    0  0.0035  0.0035 -1  ro_steel  E_steel  0.3          % Antiroll vertical arm
    4203  4204  1    0  0.0035  0.0035 -1  ro_steel  E_steel  0.3          % Antiroll oblique arm
    ];
RBE_Rear_Antiroll_bar_l = [
       4202 1 4212 1                                                       % Antiroll-Hardware joint
       4202 2 4212 2                                                       % Antiroll-Hardware joint
       4202 3 4212 3                                                       % Antiroll-Hardware joint
       4202 6 4212 6                                                       % Antiroll-Hardware joint
       ];

% Mirroring
% The left entites 42xx are duplicated for the right side 43xx
Geo_Rear_Antiroll_bar_r = Geo_Rear_Antiroll_bar_l;                         % Defining the Geometry for the right side
Geo_Rear_Antiroll_bar_r(:,1) = Geo_Rear_Antiroll_bar_r(:,1)+100;           % Naming the right side nodes 
Geo_Rear_Antiroll_bar_r(:,3) = Geo_Rear_Antiroll_bar_r(:,3)*(-1);          % Mirror

Rod_Rear_Antiroll_bar_r = Rod_Rear_Antiroll_bar_l;                         % Defining the Rod
Rod_Rear_Antiroll_bar_r(:,[1 2]) = Rod_Rear_Antiroll_bar_r(:,[1 2])+100;   % Naming the right side nodes

RBE_Rear_Antiroll_bar_r = RBE_Rear_Antiroll_bar_l;                         % Defining the RBE
RBE_Rear_Antiroll_bar_r(:,[1 3]) = RBE_Rear_Antiroll_bar_r(:,[1 3])+100;   % Naming the right side nodes

% Assembly of entities
Geo_Rear_Antiroll_bar = [
    Geo_Rear_Antiroll_bar_l
    Geo_Rear_Antiroll_bar_r
    ];
clear Geo_Rear_Antiroll_bar_l Geo_Rear_Antiroll_bar_r
Rod_Rear_Antiroll_bar = [ 
    Rod_Rear_Antiroll_bar_l
    4204  4304  1    0  0.0035  0.0035 -1  ro_steel  E_steel 0.3
    Rod_Rear_Antiroll_bar_r
    ];
clear Rod_Rear_Antiroll_bar_l Rod_Rear_Antiroll_bar_r
RBE_Rear_Antiroll_bar = [
    RBE_Rear_Antiroll_bar_l
    RBE_Rear_Antiroll_bar_r
    ];
clear RBE_Rear_Antiroll_bar_l RBE_Rear_Antiroll_bar_r
end

% WHICH ANTI-ROLL BAR DO YOU WANT TO INSERT?
        switch bars_which
            case 1
                 disp('With FRONT ANTI-ROLL BAR')
                 % Model
                 Model.Geo = [
                     Geo_Vehicle(1:(find(Geo_Vehicle(:)==5004))-1,:)
                     Geo_Front_Antiroll_bar
                     Geo_Vehicle(find(Geo_Vehicle(:)==5004):end,:)
                     ];
                 Model.Rod = [
                     Rod_Vehicle
                     Rod_Front_Antiroll_bar  
                     ];
                 Model.RBE = [
                     RBE_chassis(1:26,:)
                     506 1 4001 1                                          % FL Antiroll bar-low arm joint
                     506 2 4001 2                                          % FL Antiroll bar-low arm joint
                     506 3 4001 3                                          % FL Antiroll bar-low arm joint
                     507 1 4101 1                                          % FR Antiroll bar-low arm joint
                     507 2 4101 2                                          % FR Antiroll bar-low arm joint
                     507 3 4101 3                                          % FR Antiroll bar-low arm joint
                     RBE_chassis(27:end,:)
                     RBE_Front_Antiroll_bar   
                     5004 1 4004 1                                         % FL Hook Antiroll-Chassis
                     5004 3 4004 3                                         % FL Hook Antiroll-Chassis
                     5104 1 4104 1                                         % FR Hook Antiroll-Chassis
                     5104 3 4104 3                                         % FR Hook Antiroll-Chassis
                     ];
            case 2
                disp('With REAR ANTI-ROLL BAR')
      
                % Model
                Model.Geo = [
                    Geo_Vehicle(1:(find(Geo_Vehicle(:)==5004))-1,:)
                    Geo_Rear_Antiroll_bar  
                    Geo_Vehicle(find(Geo_Vehicle(:)==5004):end,:)
                    ];
                Model.Rod = [
                    Rod_Vehicle
                    Rod_Rear_Antiroll_bar
                    ];     
                Model.RBE = [
                     RBE_chassis(1:26,:)
                     508 1 4201 1                                          % RL Antiroll bar-low arm joint
                     508 2 4201 2                                          % RL Antiroll bar-low arm joint
                     508 3 4201 3                                          % RL Antiroll bar-low arm joint
                     509 1 4301 1                                          % RR Antiroll bar-low arm joint
                     509 2 4301 2                                          % RR Antiroll bar-low arm joint
                     509 3 4301 3                                          % RR Antiroll bar-low arm joint                                                
                     RBE_chassis(27:end,:)
                     RBE_Rear_Antiroll_bar   
                     5204 1 4204 1                                         % RL Hook Antiroll-Chassis
                     5204 3 4204 3                                         % RL Hook Antiroll-Chassis
                     5304 1 4304 1                                         % RR Hook Antiroll-Chassis
                     5304 3 4304 3                                         % RR Hook Antiroll-Chassis
                     ];
            case 3
                disp('With BOTH ANTI-ROLL BARS')
                
                % Model
                Model.Geo = [
                    Geo_Vehicle(1:(find(Geo_Vehicle(:)==5004))-1,:)
                    Geo_Front_Antiroll_bar
                    Geo_Rear_Antiroll_bar
                    Geo_Vehicle(find(Geo_Vehicle(:)==5004):end,:)
                    ];
                Model.Rod = [
                    Rod_Vehicle
                    Rod_Front_Antiroll_bar
                    Rod_Rear_Antiroll_bar
                    ];
               Model.RBE = [
                     RBE_chassis(1:26,:)
                     506 1 4001 1                                          % FL Antiroll bar-low arm joint
                     506 2 4001 2                                          % FL Antiroll bar-low arm joint
                     506 3 4001 3                                          % FL Antiroll bar-low arm joint
                     506 6 4001 6                                          % FL Antiroll bar-low arm joint
                     507 1 4101 1                                          % FR Antiroll bar-low arm joint
                     507 2 4101 2                                          % FR Antiroll bar-low arm joint
                     507 3 4101 3                                          % FR Antiroll bar-low arm joint
                     507 6 4101 6                                          % FR Antiroll bar-low arm joint
                     508 1 4201 1                                          % RL Antiroll bar-low arm joint
                     508 2 4201 2                                          % RL Antiroll bar-low arm joint
                     508 3 4201 3                                          % RL Antiroll bar-low arm joint
                     508 6 4201 6                                          % RL Antiroll bar-low arm joint
                     509 1 4301 1                                          % RR Antiroll bar-low arm joint
                     509 2 4301 2                                          % RR Antiroll bar-low arm joint
                     509 3 4301 3                                          % RR Antiroll bar-low arm joint                                                
                     509 6 4301 6                                          % RR Antiroll bar-low arm joint 
                     RBE_chassis(27:end,:)
                     RBE_Front_Antiroll_bar 
                     RBE_Rear_Antiroll_bar 
                     5004 1 4004 1                                         % FL Hook Antiroll-Chassis
                     5004 3 4004 3                                         % FL Hook Antiroll-Chassis
                     5104 1 4104 1                                         % FR Hook Antiroll-Chassis
                     5104 3 4104 3                                         % FR Hook Antiroll-Chassis
                     5204 1 4204 1                                         % RL Hook Antiroll-Chassis
                     5204 3 4204 3                                         % RL Hook Antiroll-Chassis
                     5304 1 4304 1                                         % RR Hook Antiroll-Chassis
                     5304 3 4304 3                                         % RR Hook Antiroll-Chassis
                     ];
               
        end
end
disp('---------------------------------------------------------------------')

Model.Els = [
    106  1  206  1  Car.FSusp.k.x                                          % FL x component spring
    106  2  206  2  Car.FSusp.k.y                                          % FL y component spring
    106  3  206  3  Car.FSusp.k.z                                          % FL z component spring
    107  1  207  1  Car.FSusp.k.x                                          % FR x component spring
    107  2  207  2  Car.FSusp.k.y                                          % FR y component spring
    107  3  207  3  Car.FSusp.k.z                                          % FR z component spring
    108  1  208  1  Car.RSusp.k.x                                          % RL x component spring
    108  2  208  2  Car.RSusp.k.y                                          % RL y component spring
    108  3  208  3  Car.RSusp.k.z                                          % RL z component spring
    109  1  209  1  Car.RSusp.k.x                                          % RR x component spring
    109  2  209  2  Car.RSusp.k.y                                          % RR y component spring
    109  3  209  3  Car.RSusp.k.z                                          % RR z component spring
    306  3  601  3  Car.FTyres.k                                           % FL wheel
    307  3  701  3  Car.FTyres.k                                           % FR wheel
    308  3  801  3  Car.RTyres.k                                           % RL wheel
    309  3  901  3  Car.RTyres.k                                           % RR wheel
    ]; 
Model.Dmp = [
    106  1  206  1  Car.FSusp.c.x                                          % FL x component damper
    106  2  206  2  Car.FSusp.c.y                                          % FL y component damper    
    106  3  206  3  Car.FSusp.c.z                                          % FL z component damper
    107  1  207  1  Car.FSusp.c.x                                          % FR x component damper
    107  2  207  2  Car.FSusp.c.y                                          % FR y component damper
    107  3  207  3  Car.FSusp.c.z                                          % FR z component damper
    108  1  208  1  Car.RSusp.c.x                                          % RL x component damper
    108  2  208  2  Car.RSusp.c.y                                          % RL y component damper
    108  3  208  3  Car.RSusp.c.z                                          % RL z component damper
    109  1  209  1  Car.RSusp.c.x                                          % RR x component damper
    109  2  209  2  Car.RSusp.c.y                                          % RR y component damper
    109  3  209  3  Car.RSusp.c.z                                          % RR z component damper
    306  3  601  3  Car.FTyres.c                                           % FL wheel
    307  3  701  3  Car.FTyres.c                                           % FR wheel
    308  3  801  3  Car.RTyres.c                                           % RL wheel
    309  3  901  3  Car.RTyres.c                                           % RR wheel
    ];

Model.BCs = [
    100  1                                                                 % x traslation of G
    100  2                                                                 % y traslation of G
    100  6                                                                 % z rotation of G
    306  1                                                                 % Contact point of FL wheel
    306  2                                                                 % Contact point of FL wheel
    306  3                                                                 % Contact point of FL wheel
    306  4                                                                 % Contact point of FL wheel
    306  5                                                                 % Contact point of FL wheel
    306  6                                                                 % Contact point of FL wheel
    307  1                                                                 % Contact point of FR wheel
    307  2                                                                 % Contact point of FR wheel
    307  3                                                                 % Contact point of FR wheel
    307  4                                                                 % Contact point of FR wheel
    307  5                                                                 % Contact point of FR wheel
    307  6                                                                 % Contact point of FR wheel   
    308  1                                                                 % Contact point of RL wheel
    308  2                                                                 % Contact point of RL wheel
    308  3                                                                 % Contact point of RL wheel
    308  4                                                                 % Contact point of RL wheel
    308  5                                                                 % Contact point of RL wheel
    308  6                                                                 % Contact point of RL wheel
    309  1                                                                 % Contact point of RR wheel
    309  2                                                                 % Contact point of RR wheel
    309  3                                                                 % Contact point of RR wheel
    309  4                                                                 % Contact point of RR wheel
    309  5                                                                 % Contact point of RR wheel
    309  6                                                                 % Contact point of RR wheel
    601  6                                                                 % FL wheel centre
    701  6                                                                 % FR wheel centre
    801  6                                                                 % RL wheel centre
    901  6                                                                 % RR wheel centre
    ];

Simul.RefSys = 'xyz';
Simul.axis_par = [-(Car.a2+0.3) +(Car.a1+0.3) -0.4 +0.4 -0.2 +0.6];
Simul.view_par = [60 30];


Simul.Par_name = 'Stiffness[N/m]';

