% FRONT SPRINGS
% The order of the spring follows:
% 1. blue (nominal)
% 2. gold (soft)
% 3. red (hard)
% 4. orange (extra hard)

% nominal(measured)_characteristcs_front_springs.txt are text matrix 3x4
% each column corresponds to a spring type
% 1^ row: wire diameter 
% 2^ row: height or total heigh (nominal case)
% 3^ row: number of active spires

count_fr = menu('','Front','Rear');
switch count_fr
    case 1
        disp('%%-----------------------------------------%%')
        disp('You chose Front Spring')
        file = 'front.txt';
        k_nom = [2046.2   1816.9   2275.6   2504.9].';                     % [N/m] Nominal spring stiffness
    case 2
        disp('%%-----------------------------------------%%')
        disp('You chose Rear Spring')
        file = 'rear.txt';
        k_nom = [1411.2   1199.5   1640.5   1887.5].';                     % [N/m] Nominal spring stiffness
end

count_type = menu('Spring type','Blue','Gold','Red','Orange');
switch count_type
    case 1
        disp('%%-----------------------------------------%%')
        disp('You chose Blue Spring')
    case 2
        disp('%%-----------------------------------------%%')
        disp('You chose Gold Spring')
    case 3
        disp('%%-----------------------------------------%%')
        disp('You chose Red Spring')
    case 4
        disp('%%-----------------------------------------%%')
        disp('You chose Orange Spring')
end
disp('%%-----------------------------------------%%')

k_nom = k_nom(count_type,1);
D_in = 0.0326;                                                             % [m] Inner diameter
N_inact = 3/4;                                                             % [-] Inactive sprires
Nodes= 16;                                                                 % [-] Nodes per spire

properties = load(file);

d_w = properties(1,count_type);                                            % [m] Wire diameter
H = properties(2,count_type);                                              % [m] Spring height
N_act = properties(3,count_type);                                          % [-] active spires
D_av = D_in+d_w;                                                           % [m] Average diameter of the spires

% Material
ro = 7700;                                                                 % [kg/m3] Density
E = 210e9;                                                                 % [N/m2] Young modulus
ni = 0.3;                                                                  % [-] Poissont modulus

Model.Geo = [
    100  0 0  0
    101  0 0 -H
    ];

Model.Rod = [];
Model.RJs = [];

[Model.Geo,Model.Rod,Model.RJs] = ...
    Spring(Model.Geo,Model.Rod,Model.RJs,d_w,D_av,H, ...
    N_act,N_inact,1,Nodes,100,101,200,ro,E,ni);

Model.BCs = [
    100 1
    100 2
    100 3
    100 4
    100 5
    100 6
    101 1
    101 2
    101 4
    101 5
    ];
Model.BCs = sortrows(Model.BCs,1);

Model.FMs = [101 3 -20];

