%% k sperimentale - fitting data
close all
clear all 
clc
% MASSE MISURATE
m_05 = 0.4765;                   % 0.5 kg massa nominale 
m_1 = 1.0136;                    % 1.0 kg massa nominale
m_2a = 1.955;                    % 2.0 kg massa nominale
m_2b = 1.9771;                   % 2.0 kg massa nominale
m_chain = 0.0603;                % 60.3 g catena + moschettone

% FRONT
 for front = 1 : 4 
     if front == 1
         file = 'LOSB2965_BF.txt'; 
         disp('FRONT BLUE')
     end
     if front == 2
         file = 'LOSB2964_YF.txt'; 
         disp('FRONT GOLD')
     end
     if front == 3
         file = 'LOSB2967_OF.txt';     
         disp('FRONT ORANGE')
     end
     if front == 4
         file = 'LOSB2966_RF.txt'; 
         disp('FRONT RED')
     end
     data = load(file);
offset = data(1,1)*ones(8,1);                                              % distanza lamiera-mirino a vuoto (senza catena n peso)
l = data(2:9,1);                                                           % distanza lamiera-mirino sottocarico 
delta = offset-l;                                                          % allungamento [m]
F = [m_05 m_1 (m_05+m_1) m_2a (m_2a+m_05) (m_2a+m_1) (m_2a+m_1+m_05) (m_2a+m_2b)]'*9.81+ones(8,1)*m_chain*9.81; % vettore Forze con passo 0.5 kg
p = polyfix(delta,F,1,0,0);                                                % polyfit                                                

figure(1)
set(gcf,'Color',[1 1 1]);
set(gcf,'Name','Front Springs characteristic');
plot_color = strvcat('b','y','k','r');
plot_line = strvcat('-',':','-.','--');
plot_symbol = strvcat('o','x','v','*');
plot_markersize = [6 7 6 7];
plot(delta,F,[plot_symbol(front) plot_color(front)],'MarkerSize',plot_markersize(front))
hold on
plot([0;delta],[0;polyval(p,delta)],[plot_line(front) plot_color(front)],'Linewidth',2);     
hold on
xlabel('\Delta x [m]','Fontsize',12)
ylabel('Force [N]','Fontsize',12)
zoom on

disp(['k = ',num2str(p(1)),' N/m']);
% coeff di determinazione
mdl = fitlm(delta,F);
r2 = mdl.Rsquared.Adjusted;
disp(['R2 = ',num2str(r2)]);
xlim([0 0.03]) 
 end
legend({'Blue spring','Blue spring','Gold spring','Gold spring','Orange spring','Orange spring','Red spring','Red spring'},'Location', 'southeast')
xlim([0 0.03]) 
ylim([0 45])

% REAR
 for rear = 1 : 3 
  if rear == 1
      file = 'LOSB2972_BR.txt';
      disp('REAR BLUE')
  end
   if rear == 2
       file = 'LOSB2973_OR.txt'; 
      disp('REAR ORANGE')
   end
   if rear == 3
       file = 'LOSB2971_RR.txt'; 
       disp('REAR RED')
   end
 
data = load(file);
offset = data(1,1)*ones(8,1);                                              % distanza lamiera-mirino a vuoto (senza catena n peso)
l = data(2:9,1);                                                           % distanza lamiera-mirino sottocarico 
delta = offset-l;                                                          % allungamento [m]
F = [m_05 m_1 (m_05+m_1) m_2a (m_2a+m_05) (m_2a+m_1) (m_2a+m_1+m_05) (m_2a+m_2b)]'*9.81+ones(8,1)*m_chain*9.81; % vettore Forze con passo 0.5 kg
p = polyfix(delta,F,1,0,0);                                                % polyfit                                                

figure(2)
set(gcf,'Color',[1 1 1]);
set(gcf,'Name','Rear Springs characteristic');
plot_color = strvcat('b','k','r');
plot_line = strvcat('-','-.','--');
plot_symbol = strvcat('o','v','*');
plot_markersize = [6 6 7];
plot(delta,F,[plot_symbol(rear) plot_color(rear)],'MarkerSize',plot_markersize(rear))
hold on
plot([0;delta],[0;polyval(p,delta)],[plot_line(rear) plot_color(rear)],'Linewidth',2);     
hold on
xlabel('\Delta x [m]','Fontsize',12)
ylabel('Force [N]','Fontsize',12)
zoom on
                                      
disp(['k = ',num2str(p(1)),' N/m']);
% R2
mdl = fitlm(delta,F);
r2 = mdl.Rsquared.Adjusted;
disp(['R2 = ',num2str(r2)]);
 end
legend({'Blue spring','Blue spring','Orange spring','Orange spring','Red spring','Red spring'},'Location', 'southeast')
xlim([0 0.03]) 
ylim([0 45])

