close all;
clear all;
clc;
%In this script I am going to make a comparison between the mass calculated
%by Lupos/theoretical/measured and try to get the correct density of the
%material

%% Theoretical masses [kg]
ro=7700;                                                                   %density [kg/m^3]
d_in=0.0326;                                                               %Inner helix diameter [m]
front='front.txt';
properties=load(front);
dw_f=properties(1,:);                                                      %wire diameters of front springs[m]
H_f=properties(2,:);                                                       % height [m]
s_f=properties(3,:);                                                       %active spires of front springs [-]
ns_f=properties(4,:);                                                      %inactive spires of front springs [-]
dh_f=dw_f+d_in*ones(size(dw_f));                                           %helix diameters of front springs [m]
p_f=H_f./s_f;                                                              %step
m_t_f=ro.*pi/4.*dw_f.^2.*((ns_f.*dh_f.*pi)+(s_f.*sqrt(p_f.^2+(dh_f.*pi).^2))); %theoretical masses of front springs [m]
disp(['Theoretical masses of Front Springs']);
disp(['Blue: ',num2str(m_t_f(1)),'kg']);
disp(['Gold: ',num2str(m_t_f(2)),'kg']);
disp(['Red: ',num2str(m_t_f(3)),'kg']);
disp(['Orange: ',num2str(m_t_f(4)),'kg']);
rear='rear.txt';
properties=load(rear);
dw_r=properties(1,:);                                                      %wire diameters of rear springs[m]
H_r=properties(2,:);                                                       % height [m]
s_r=properties(3,:);                                                       %active spires of rear springs [-]
ns_r=properties(4,:);                                                      %inactive spires of rear springs [-]
dh_r=dw_r+d_in*ones(size(dw_r));                                           %helix diameters of front springs [m]
p_r=H_r./s_r;                                                              %step
m_t_r=ro.*pi/4.*dw_r.^2.*((ns_r.*dh_r.*pi)+(s_r.*sqrt(p_r.^2+(dh_r.*pi).^2))); %theoretical masses of rear springs [m]
disp(['Theoretical masses of Rear Springs']);
disp(['Blue: ',num2str(m_t_r(1)),'kg']);
disp(['Red: ',num2str(m_t_r(2)),'kg']);
disp(['Orange: ',num2str(m_t_r(3)),'kg']);
disp('');
%% Lupos masses
m_l_f=[0.036383 0.03347 0.04024 0.04471]; %front spring [kg]
m_l_r=[0.034435 0.037233  0.040169]; %rear spring [kg]
disp(['Lupos masses of Front Springs']);
disp(['Blue: ',num2str(m_l_f(1)),'kg']);
disp(['Gold: ',num2str(m_l_f(2)),'kg']);
disp(['Red: ',num2str(m_l_f(3)),'kg']);
disp(['Orange: ',num2str(m_l_f(4)),'kg']);
disp(['Lupos masses of Rear Springs']);
disp(['Blue: ',num2str(m_l_r(1)),'kg']);
disp(['Red: ',num2str(m_l_r(2)),'kg']);
disp(['Orange: ',num2str(m_l_r(3)),'kg']);
disp(['-----------------------------------------']);
%% Measured masses
m_m_f=[0.0465 0.04315 0.05125 0.0568]; %front spring [kg] AGGIUNGERE LA BLU
m_m_r=[0.0434 0.04585 0.05035]; %rear spring [kg]
disp(['Measured masses of Front Springs']);
disp(['Blue: ',num2str(m_m_f(1)),'kg']);
disp(['Gold: ',num2str(m_m_f(2)),'kg']);
disp(['Red: ',num2str(m_m_f(3)),'kg']);
disp(['Orange: ',num2str(m_m_f(4)),'kg']);
disp(['Measured masses of Rear Springs']);
disp(['Blue: ',num2str(m_m_r(1)),'kg']);
disp(['Red: ',num2str(m_m_r(2)),'kg']);
disp(['Orange: ',num2str(m_m_r(3)),'kg']);
disp(['-----------------------------------------']);
disp('')
%% Percentage error between Theoretical and Measured masses
err_tm_f=(m_t_f-m_m_f)./m_m_f*100; %front [%]
err_tm_r=(m_t_r-m_m_r)./m_m_r*100; %rear [%]
disp(['Percentage error between Theoretical and Measured FRONT massess']);
disp(['Blue: ',num2str(err_tm_f(1)),'%']);
disp(['Gold: ',num2str(err_tm_f(2)),'%']);
disp(['Red: ',num2str(err_tm_f(3)),'%']);
disp(['Orange: ',num2str(err_tm_f(4)),'%']);
disp(['Percentage error between Theoretical and Measured REAR massess']);
disp(['Blue: ',num2str(err_tm_r(1)),'%']);
disp(['Red: ',num2str(err_tm_r(2)),'%']);
disp(['Orange: ',num2str(err_tm_r(3)),'%']);
disp(['-----------------------------------------']);
%% Percentage error between Lupos and Measured masses
err_lm_f=(m_l_f-m_m_f)./m_m_f*100; %front [%]
err_lm_r=(m_l_r-m_m_r)./m_m_r*100; %rear [%]
disp(['Percentage error between Lupos and Measured FRONT masses ']);
disp(['Blue: ',num2str(err_lm_f(1)),'%']);
disp(['Gold: ',num2str(err_lm_f(2)),'%']);
disp(['Red: ',num2str(err_lm_f(3)),'%']);
disp(['Orange: ',num2str(err_lm_f(4)),'%']);
disp(['Percentage error between Lupos and Measured REAR masses']);
disp(['Blue: ',num2str(err_lm_r(1)),'%']);
disp(['Red: ',num2str(err_lm_r(2)),'%']);
disp(['Orange: ',num2str(err_lm_r(3)),'%']);
disp(['-----------------------------------------']);
%% Contribution of inactive spires
m_ns_f=ro.*pi/4.*dw_f.^2.*(ns_f.*dh_f.*pi);                                % mass of inactive FRONT spires  
m_ns_r=ro.*pi/4.*dw_r.^2.*(ns_r.*dh_r.*pi);                                % mass of inactive REAR spires
disp(['Contribution of inactive spires FRONT']);
disp(['Blue: ',num2str(m_ns_f(1)),'kg']);
disp(['Gold: ',num2str(m_ns_f(2)),'kg']);
disp(['Red: ',num2str(m_ns_f(3)),'kg']);
disp(['Orange: ',num2str(m_ns_f(4)),'kg']);
disp(['Contribution of inactive spires REAR']);
disp(['Blue: ',num2str(m_ns_r(1)),'kg']);
disp(['Red: ',num2str(m_ns_r(2)),'kg']);
disp(['Orange: ',num2str(m_ns_r(3)),'kg']);
disp(['-----------------------------------------']);
%Modified LUPOS with contribution of inactive spires
m_modif_f=m_l_f+m_ns_f;                                                    %front
m_modif_r=m_l_r+m_ns_r;                                                    %rear
disp(['Modified LUPOS FRONT']);
disp(['Blue: ',num2str(m_modif_f(1)),'kg']);
disp(['Gold: ',num2str(m_modif_f(2)),'kg']);
disp(['Red: ',num2str(m_modif_f(3)),'kg']);
disp(['Orange: ',num2str(m_modif_f(4)),'kg']);
disp(['Modified LUPOS REAR']);
disp(['Blue: ',num2str(m_modif_r(1)),'kg']);
disp(['Red: ',num2str(m_modif_r(2)),'kg']);
disp(['Orange: ',num2str(m_modif_r(3)),'kg']);
disp(['-----------------------------------------']);
%% Percentage error between Modified Lupos and Measured masses
err_modif_f=(m_modif_f-m_m_f)./m_m_f*100; %front [%]
err_modif_r=(m_modif_r-m_m_r)./m_m_r*100; %rear [%]
disp(['Percentage error between Modified Lupos and Measured FRONT masses ']);
disp(['Blue: ',num2str(err_modif_f(1)),'%']);
disp(['Gold: ',num2str(err_modif_f(2)),'%']);
disp(['Red: ',num2str(err_modif_f(3)),'%']);
disp(['Orange: ',num2str(err_modif_f(4)),'%']);
disp(['Percentage error between Modified Lupos and Measured REAR masses']);
disp(['Blue: ',num2str(err_modif_r(1)),'%']);
disp(['Red: ',num2str(err_modif_r(2)),'%']);
disp(['Orange: ',num2str(err_modif_r(3)),'%']);
disp(['-----------------------------------------']);