close all;
clear all;
clc;
%In this script I am going to make a comparison between stiffnesses
%nominal/calculated by Lupos/theoretical/measured 
%% Nominal Stiffness (Catalog)
k_n_f = [2046.24 1816.92 2275.56 2504.88];                                   %front spring [N/m]
k_n_r = [1411.2 1640.52 1887.48];                                            %rear spring [N/m]
disp(['Nominal Stiffness of Front Springs']);
disp(['Blue: ',num2str(k_n_f(1)),' N/m']);
disp(['Gold: ',num2str(k_n_f(2)),' N/m']);
disp(['Red: ',num2str(k_n_f(3)),' N/m']);
disp(['Orange: ',num2str(k_n_f(4)),' N/m']);
disp(['Nominal Stiffness of Rear Springs']);
disp(['Blue: ',num2str(k_n_r(1)),' N/m']);
disp(['Red: ',num2str(k_n_r(2)),' N/m']);
disp(['Orange: ',num2str(k_n_r(3)),' N/m']);
disp(['-----------------------------------------']);

%% Theoretical stiffness [N/m]
E = 210e9;                                                                   %Young modulus [Pa]
ni = 0.3;                                                                    %Poisson
G = E/(2*(1+ni));                                                            %Tangential modulus [Pa]
d_in = 0.0326;                                                               %Inner helix diameter [m]
front = 'front.txt';
properties = load(front);
dw_f = properties(1,:);                                                      %wire diameters of front springs[m]
s_f = properties(3,:);                                                       %active spires of front springs [-]
dh_f = dw_f+d_in*ones(size(dw_f));                                           %helix diameters of front springs [m]
k_t_f = (G*dw_f.^4)./(8*s_f.*dh_f.^3);                                       %theoretical stiffesses of front springs [m]
disp(['Theoretical Stiffness of Front Springs']);
disp(['Blue: ',num2str(k_t_f(1)),' N/m']);
disp(['Gold: ',num2str(k_t_f(2)),' N/m']);
disp(['Red: ',num2str(k_t_f(3)),' N/m']);
disp(['Orange: ',num2str(k_t_f(4)),' N/m']);
rear = 'rear.txt';
properties = load(rear);
dw_r = properties(1,:);                                                    %wire diameters of front springs[m]
s_r = properties(3,:);                                                     %active spires of front springs [-]
dh_r = dw_r+d_in*ones(size(dw_r));                                         %helix diameters of front springs [m]
k_t_r = (G*dw_r.^4)./(8*s_r.*dh_r.^3);                                     %theoretical stiffesses of front springs [m]
disp(['Theoretical Stiffness of Rear Springs']);
disp(['Blue: ',num2str(k_t_r(1)),' N/m']);
disp(['Red: ',num2str(k_t_r(2)),' N/m']);
disp(['Orange: ',num2str(k_t_r(3)),' N/m']);
disp(['-----------------------------------------']);
%% Lupos Stiffness
k_l_f=[2060.3168 1810.611 2287.2324 2501.6046]; %front spring [N/m] 
k_l_r=[1408.2789 1623.6958 1861.3019]; %rear spring [N/m] %AGGIUNGERE LA REAR BLUE 
disp(['Lupos Stiffness of Front Springs']);
disp(['Blue: ',num2str(k_l_f(1)),' N/m']);
disp(['Gold: ',num2str(k_l_f(2)),' N/m']);
disp(['Red: ',num2str(k_l_f(3)),' N/m']);
disp(['Orange: ',num2str(k_l_f(4)),' N/m']);
disp(['Lupos Stiffness of Rear Springs']);
disp(['Blue: ',num2str(k_l_r(1)),' N/m']);
disp(['Red: ',num2str(k_l_r(2)),' N/m']);
disp(['Orange: ',num2str(k_l_r(3)),' N/m']);
disp(['-----------------------------------------']);
%% Measured Stiffness
k_m_f=[2.0453e+03 1.8771e+03 2206.50 2487.40]; %front spring [N/m]
k_m_r=[1.3914e+03  1.6501e+03 1.8379e+03]; %rear spring [N/m]
disp(['Measured Stiffness of Front Springs']);
disp(['Blue: ',num2str(k_m_f(1)),' N/m']);
disp(['Gold: ',num2str(k_m_f(2)),' N/m']);
disp(['Red: ',num2str(k_m_f(3)),' N/m']);
disp(['Orange: ',num2str(k_m_f(4)),' N/m']);
disp(['Measured Stiffness of Rear Springs']);
disp(['Blue: ',num2str(k_m_r(1)),' N/m']);
disp(['Red: ',num2str(k_m_r(2)),' N/m']);
disp(['Orange: ',num2str(k_m_r(3)),' N/m']);
disp(['-----------------------------------------']);
%% Percentage error between Theoretical and Nominal Stiffness
err_tn_f = (k_t_f-k_n_f)./k_n_f*100;                                       %front [%]
err_tn_r = (k_t_r-k_n_r)./k_n_r*100;                                       %rear [%]
disp(['Percentage error between Theoretical and Nominal FRONT Stiffness']);
disp(['Blue: ',num2str(err_tn_f(1)),'%']);
disp(['Gold: ',num2str(err_tn_f(2)),'%']);
disp(['Red: ',num2str(err_tn_f(3)),'%']);
disp(['Orange: ',num2str(err_tn_f(4)),'%']);
disp(['Percentage error between Theoretical and Nominal REAR Stiffness']);
disp(['Blue: ',num2str(err_tn_r(1)),'%']);
disp(['Red: ',num2str(err_tn_r(2)),'%']);
disp(['Orange: ',num2str(err_tn_r(3)),'%']);
disp(['-----------------------------------------']);
% %% Percentage error between Lupos and Nominal Stiffness
err_ln_f = (k_l_f-k_n_f)./k_n_f*100;                                       %front [%]
err_ln_r = (k_l_r-k_n_r)./k_n_r*100;                                       %rear [%]
disp(['Percentage error between Lupos and Nominal FRONT Stiffness']);
disp(['Blue: ',num2str(err_ln_f(1)),'%']);
disp(['Gold: ',num2str(err_ln_f(2)),'%']);
disp(['Red: ',num2str(err_ln_f(3)),'%']);
disp(['Orange: ',num2str(err_ln_f(4)),'%']);
disp(['Percentage error between Lupos and Nominal REAR Stiffness']);
disp(['Blue: ',num2str(err_ln_r(1)),'%']);
disp(['Red: ',num2str(err_ln_r(2)),'%']);
disp(['Orange: ',num2str(err_ln_r(3)),'%']);
disp(['-----------------------------------------']);
%% Percentage error between Measured and Nominal Stiffness
err_mn_f=(k_m_f-k_n_f)./k_n_f*100; %front [%]
err_mn_r=(k_m_r-k_n_r)./k_n_r*100; %rear [%]
disp(['Percentage error between Measured and Nominal FRONT Stiffness']);
disp(['Blue: ',num2str(err_mn_f(1)),'%']);
disp(['Gold: ',num2str(err_mn_f(2)),'%']);
disp(['Red: ',num2str(err_mn_f(3)),'%']);
disp(['Orange: ',num2str(err_mn_f(4)),'%']);
disp(['Percentage error between Measured and Nominal REAR Stiffness']);
disp(['Blue: ',num2str(err_mn_r(1)),'%']);
disp(['Red: ',num2str(err_mn_r(2)),'%']);
disp(['Orange: ',num2str(err_mn_r(3)),'%']);
disp(['-----------------------------------------']);